@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import BaseModel
 
 
@@ -12,8 +10,3 @@ class WatchmenNotebook(BaseModel):
 
 
 
-#
-# test = WatchmenNotebook(name="A",storageLocation="")
-# print(test.json())
-
-
