@@ -1,5 +1,7 @@
 import os
 
+from pandas import DataFrame
+
 from ml_sdk.ml.sdk.watchmen.sdk import load_dataset_by_name, push_notebook_to_watchmen
 from ml_sdk.ml.unitls import get_notebook, get_environment
 
@@ -22,14 +24,10 @@ class WatchmenClient(object):
             print("push notebook successfully")
         return notebook
 
-    def save_topic_dataset(self, topic_name: str, dataset):
+    def save_topic_dataset(self, topic_name: str, dataset:DataFrame):
         pass
 
 
     def register_model(self):
         pass
 
-#
-# client  = WatchmenClient(token="0Z6ag50cdIPamBIgf8KfoQ")
-# df = client.load_dataset("DEMO")
-# print(df)
